@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2015 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,11 +32,12 @@ public:
 		ACCEPT_ALL
 	} EAcceptType;
 
-	CListener(unsigned short uPort, const CString& sBindHost, bool bSSL, EAddrType eAddr, EAcceptType eAccept) {
+	CListener(unsigned short uPort, const CString& sBindHost, const CString& sURIPrefix, bool bSSL, EAddrType eAddr, EAcceptType eAccept) {
 		m_uPort = uPort;
 		m_sBindHost = sBindHost;
 		m_bSSL = bSSL;
 		m_eAddr = eAddr;
+		m_sURIPrefix = sURIPrefix;
 		m_pListener = NULL;
 		m_eAcceptType = eAccept;
 	}
@@ -49,6 +50,7 @@ public:
 	unsigned short GetPort() const { return m_uPort; }
 	const CString& GetBindHost() const { return m_sBindHost; }
 	CRealListener* GetRealListener() const { return m_pListener; }
+	const CString& GetURIPrefix() const { return m_sURIPrefix; }
 	EAcceptType GetAcceptType() const { return m_eAcceptType; }
 	// !Getters
 
@@ -65,13 +67,14 @@ protected:
 	EAddrType       m_eAddr;
 	unsigned short  m_uPort;
 	CString         m_sBindHost;
+	CString         m_sURIPrefix;
 	CRealListener*  m_pListener;
 	EAcceptType     m_eAcceptType;
 };
 
 class CRealListener : public CZNCSock {
 public:
-	CRealListener(CListener *pParent) : CZNCSock(), m_pParent(pParent) {}
+	CRealListener(CListener& listener) : CZNCSock(), m_Listener(listener) {}
 	virtual ~CRealListener();
 
 	virtual bool ConnectionFrom(const CString& sHost, unsigned short uPort);
@@ -79,18 +82,19 @@ public:
 	virtual void SockError(int iErrno, const CString& sDescription);
 
 private:
-	CListener* m_pParent;
+	CListener& m_Listener;
 };
 
 class CIncomingConnection : public CZNCSock {
 public:
-	CIncomingConnection(const CString& sHostname, unsigned short uPort, CListener::EAcceptType eAcceptType);
+	CIncomingConnection(const CString& sHostname, unsigned short uPort, CListener::EAcceptType eAcceptType, const CString& sURIPrefix);
 	virtual ~CIncomingConnection() {}
 	virtual void ReadLine(const CString& sData);
 	virtual void ReachedMaxBuffer();
 
 private:
 	CListener::EAcceptType m_eAcceptType;
+	const CString m_sURIPrefix;
 };
 
 #endif // !_LISTENER_H
